<?php
/**
 * This is the entrypoint for the locrMAPS WordPress plugin.
 *
 * @package locrMAPS
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMaps\DDD\ValueObjects\GeneralOptions;

use Locr\WordPress\Plugin\LocrMaps\Plugin;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for the access key.
 */
final class AccessKey implements \Stringable {
	public const ATTRIBUTE_KEY = 'access-key';
	public const OPTION_KEY    = Plugin::SLUG . '_access_key';

	/**
	 * The constructor.
	 *
	 * @param string $access_key The access key.
	 * @throws \InvalidArgumentException If the access key is invalid.
	 */
	public function __construct( private string $access_key = '' ) {
		if ( '' !== $access_key ) {
			if ( ! preg_match( '/^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$/', $access_key ) ) {
				throw new \InvalidArgumentException( 'Invalid access key.' );
			}
		}
	}

	/**
	 * The magick getter.
	 */
	public function __toString(): string {
		return $this->access_key;
	}
}
